@@ -7,8 +7,9 @@
 #define DEFAULT_DEVICE "/dev/fd0"
 
 /* These should not exist :-) The file is deleted when not needed. */
-#define TEMP_FILE "/tmp/____floppybackup_TempMuzh"
-#define TEMP_DATA "/tmp/____floppybackup_TempData"
+/* Indeed, they need not now :) matthew@debian.org */
+/* #define TEMP_FILE "/tmp/____floppybackup_TempMuzh" */
+/* #define TEMP_DATA "/tmp/____floppybackup_TempData" */
 
 /* See archive_header */
 #define MAGICBYTES "FdBackup"				/* Saved as first bytes to disk. */
